@@ -3,7 +3,7 @@
 #' @param fun    A function to call
 #' @param iter   Objects to be iterated in each function call
 #' @param const  A list of constant arguments passed to each function call
-#' @return       Processed iterated argument list
+#' @return       Processed iterated argument list if 'iter' is a list
 check_args = function(fun, iter, const=list()) {
     if (!is.list(iter) || length(iter) == 0)
         stop("'iter' needs to be a list with at least one element")
@@ -30,4 +30,12 @@ check_args = function(fun, iter, const=list()) {
     dups = duplicated(provided)
     if (any(dups))
         stop(paste("Argument duplicated:", paste(provided[[dups]], collapse=" ")))
+
+    if (!is.data.frame(iter)) {
+        df = data.frame(..placeholder.. = seq_along(iter[[1]]))
+        for (field in names(iter))
+            df[[field]] = iter[[field]]
+        df$..placeholder.. = NULL
+        df
+    }
 }
