@@ -10,6 +10,7 @@ LSF = R6::R6Class("LSF",
         },
 
         submit_jobs = function(n_jobs, template=list(), log_worker=FALSE) {
+            template = utils::modifyList(LSF$defaults, template)
             template$n_jobs = n_jobs
             template$master = private$master
             private$job_id = template$job_name = paste0("cmq", self$id)
@@ -49,8 +50,20 @@ LSF = R6::R6Class("LSF",
 # Static method, process scheduler options and return updated object
 LSF$setup = function() {
     user_template = getOption("clustermq.template.lsf")
+    if (!is.null(user_template)) {
+        warning("scheduler-specific templates are deprecated; use clustermq.template instead")
+        LSF$template = readChar(user_template, file.info(user_template)$size)
+    }
+    user_template = getOption("clustermq.template")
     if (!is.null(user_template))
         LSF$template = readChar(user_template, file.info(user_template)$size)
+
+    user_defaults = getOption("clustermq.defaults")
+    if (!is.null(user_defaults))
+        LSF$defaults = user_defaults
+    else
+        LSF$defaults = list()
+
     LSF
 }
 
