@@ -69,7 +69,7 @@ SSH = R6::R6Class("SSH",
 
         cleanup = function() {
             rzmq::send.socket(private$proxy_socket, data=list(id="PROXY_STOP"))
-            super$cleanup()
+            success = super$cleanup()
         }
     ),
 
